﻿<?php
/**
 * email_alarms - PHP email creation and transport class.
 * @author Miguel A, Fdez.
 * Funciones necesarias para enviar un  email a los usuarios habilitados
 * para ello, con las notificaciones de las alarmas generadas por el
 * sistema: Nivel, Temperatura, Verticalidad y Mantenimiento.
 * 
 */

require_once('../model/container_db.php');
require_once('../model/centro_db.php');
require_once('../model/residuo_db.php');
require_once('../model/ubicacion_db.php');
require_once('../model/usuario_db.php');
require_once('email_data.php');
require_once('PHPMailerAutoload.php');

function send_emails($contenedor_id, $header, $fields, $footer) {
       
    $email_msg = $header . $fields . $footer;
 
    // contenedor que envía el estado de las alarmas
    $contenedor = get_container($contenedor_id);  
    
    // ubicación del contenedor
    $ubicacion = get_ubicacion($contenedor['ubicacion_id']);
       
    // centro de trabajo que se encarga del contenedor
    $centro = get_centro($ubicacion['centro_id']);
       
    // usuarios del centro de trabajo habilitados para 
    // recibir emails de alarma
    $usuarios_alarma = get_usuarios_alarma_by_centro($centro['centro_id']);
    
    /***********************
     *** Envío de emails ***
     **********************/
    
    // param 'true': lanzará excepciones que hay que manejar
    $mail = new PHPMailer(true);  

    try {
        // Habilita la información de debugado del SMTP (para pruebas)
        //0 -> Sin mensajes de debug
        //1 -> Diálogo de cliente a servidor
        //2 -> Diálogo de cliente a servidor y viceversa
        //3 -> Códigos de estado de cada fase de la conexión, además del 
        //     diálogo entre cliente y servidor/servidor y cliente
        //4 -> Devuelve a bajo nivel toda la traza de la conversación 
        //     entre cliente y servidor SMTP
        $mail->SMTPDebug = 0;

        //'echo' información de debug en texto plano
        //'html' información de debug adaptada a los navegadores
        //'error_log' información de debug a un log de error configurado en php.ini
        $mail->Debugoutput = 'error_log'; 

        $mail->IsSMTP(); // habilita SMTP
        $mail->SMTPAuth = true; // habilita autentificación
        // values: ssl - habilita transferencia segura ssl (requerida por el 
        //               servidor de correo de 'gmail' que utilizamos)
        //         tls - habilita transferencia segura tls
        $mail->SMTPSecure = 'ssl'; 

        // servidor de correo utilizado:
        $mail->Host = "XXXX"; 
        $mail->Port = 465;    
        $mail->Username = "XXXX";
        $mail->Password = "XXXX";

        // De
        $mail->SetFrom("unidad@sensora.com", "Unidad Sensora");     
        // Asunto
        $mail->Subject = "Alarma desde el centro de trabajo " . $centro['denominacion'].'.';
        
//      // dirección de respuesta
//      $mail->addReplyTo("respuesta@dominio.com", "Respuesta");
        
//      //CC and BCC
//      $mail->addCC("cc@dominio.com");
//      $mail->addBCC("bcc@dominio.com");
        
        $mail->IsHTML(true);        
        
        // Obtenemos el mensaje del e-mail en formato HTML
        $mail->Body = $email_msg;         
        
        // Mensaje para clientes de email no compatibles con HTML
        $mail->AltBody = "Para ver este mensaje, por favor utilice un visor compatible con HTML.";
        // máximo 50 caracteres por linea
        $mail->WordWrap = 50;

//      // Adjuntos
//      $mail->AddAttachment('images/myimage.gif');  
       
        // Se envia el mail a los usuarios autorizados
        foreach ($usuarios_alarma as $usuario) {
            $mail->AddAddress($usuario['email'], $usuario['nombre'] . ' ' . $usuario['apellido']);
        }
        
        $mail->Send(); // Envio
    
    }    
    catch (phpmailerException $e) {
        // Excepcion desde PHPMailer
        display_error('Error al enviar e-mail: ' . $mail->ErrorInfo);
    } 
    catch (Exception $e) {
        // Excepcion general
        display_error('Error al enviar e-mail: ' . $mail->ErrorInfo);
    }
    
}

?>