<?php

// Devuelve el dato de nivel más reciente de un contenedor determinado
function get_nivel($contenedor_id) {
    global $db;
    $query = '
        SELECT nivel_id, contenedor_id, porcentaje, es_recogida, fecha_hora
        FROM niveles n
        WHERE contenedor_id = :contenedor_id
        ORDER BY fecha_hora
        DESC LIMIT 1';
        
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':contenedor_id', $contenedor_id);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }   
}

// Añade el nivel obtenido de un contenedor  
function add_nivel($contenedor_id, $porcentaje, $es_recogida) {
    global $db;
    $query = '
        INSERT INTO niveles (contenedor_id, porcentaje, es_recogida, fecha_hora)
        VALUES (:contenedor_id, :porcentaje, :es_recogida, :fecha_hora)';

    // la fecha_hora del registro, se puede añadir directamente desde mysql
    $mysqldate = date('Y-m-d H:i:s', time());
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':contenedor_id', $contenedor_id);
        $statement->bindValue(':porcentaje', $porcentaje);
        $statement->bindValue(':es_recogida', $es_recogida);
        $statement->bindValue(':fecha_hora', $mysqldate);
        $statement->execute();
        $nivel_id = $db->lastInsertId();
        $statement->closeCursor();
        return $nivel_id;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }    
}
