<?php

// Obtiene al usuario por su identificador
function get_usuario($usuario_id) {
    global $db;
    $query = '
        SELECT * FROM usuarios WHERE usuario_id = :usuario_id';    
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':usuario_id', $usuario_id);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

// Obtiene los usuarios de un centro de trabajo determinado, que estén 
// habilitados para recibir notificaciones de alarma de los contenedores
function get_usuarios_alarma_by_centro($centro_id) {
    global $db;
    $query = 'SELECT * FROM usuarios U 
             INNER JOIN centros_usuarios R ON U.usuario_id = R.usuario_id
             INNER JOIN centros C ON R.centro_id = C.centro_id
             WHERE C.centro_id = :centro_id AND
                   U.enviar_alarmas > 0
             ORDER BY U.apellido';         
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':centro_id', $centro_id);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
