<?php
class Validate {
    private $fields;

    public function __construct() {
        $this->fields = new Fields();
    }

    public function getFields() {
        return $this->fields;
    }

    // Valida un campo de texto genérico
    public function text($name, $value,
            $required = true, $min = 1, $max = 255) {

        // Obtiene el campo
        $field = $this->fields->getField($name);

        // Si no se necesita el campo y está vacío, quita los errores y sale
        if (!$required && empty($value)) {
            $field->clearErrorMessage();
            return;
        }

        // Chequea el campo y pone o quita el mensaje de error
        if ($required && empty($value)) {
            $field->setErrorMessage('Requerido.');
        } else if (strlen($value) < $min) {
            $field->setErrorMessage('Muy corto.');
        } else if (strlen($value) > $max) {
            $field->setErrorMessage('Muy largo.');
        } else {
            $field->clearErrorMessage();
        }
    }

    // Valida un campo con un patrón genérico
    public function pattern($name, $value, $pattern, $message,
            $required = true) {

        // Obtiene el campo
        $field = $this->fields->getField($name);

        // Si no se necesita el campo y está vacío, quita los errores y sale
        if (!$required && empty($value)) {
            $field->clearErrorMessage();
            return;
        }

        // Chequea el campo y pone o quita el mensaje de error
        $match = preg_match($pattern, $value);
        if ($match === false) {
            $field->setErrorMessage('Error al comprobar el campo.');
        } else if ( $match != 1 ) {
            $field->setErrorMessage($message);
        } else {
            $field->clearErrorMessage();
        }
    }

    public function email($name, $value, $required = true) {
        $field = $this->fields->getField($name);

        // If field is not required and empty, remove errors and exit
        if (!$required && empty($value)) {
            $field->clearErrorMessage();
            return;
        }

        // Call the text method and exit if it yields an error
        $this->text($name, $value, $required);
        if ($field->hasError()) { return; }

        // Split email address on @ sign and check parts
        $parts = explode('@', $value);
        if (count($parts) < 2) {
            $field->setErrorMessage('Signo arroba requerido.');
            return;
        }
        if (count($parts) > 2) {
            $field->setErrorMessage('Solo un signo arroba permitido.');
            return;
        }
        $local = $parts[0];
        $domain = $parts[1];

        // Check lengths of local and domain parts
        if (strlen($local) > 64) {
            $field->setErrorMessage('Nombre de usuario muy largo.');
            return;
        }
        if (strlen($domain) > 255) {
            $field->setErrorMessage('Nombre de dominio muy largo.');
            return;
        }

        // Patterns for address formatted local part
        $atom = '[[:alnum:]_!#$%&\'*+\/=?^`{|}~-]+';
        $dotatom = '(\.' . $atom . ')*';
        $address = '(^' . $atom . $dotatom . '$)';

        // Patterns for quoted text formatted local part
        $char = '([^\\\\"])';
        $esc  = '(\\\\[\\\\"])';
        $text = '(' . $char . '|' . $esc . ')+';
        $quoted = '(^"' . $text . '"$)';

        // Combined pattern for testing local part
        $localPattern = '/' . $address . '|' . $quoted . '/';

        // Call the pattern method and exit if it yields an error
        $this->pattern($name, $local, $localPattern,
                'Nombre de usuario invalido.');
        if ($field->hasError()) { return; }

        // Patterns for domain part
        $hostname = '([[:alnum:]]([-[:alnum:]]{0,62}[[:alnum:]])?)';
        $hostnames = '(' . $hostname . '(\.' . $hostname . ')*)';
        $top = '\.[[:alnum:]]{2,6}';
        $domainPattern = '/^' . $hostnames . $top . '$/';

        // Call the pattern method
        $this->pattern($name, $domain, $domainPattern,
                'Dominio invalido.');
    }

    public function password($name, $password, $required = true) {
        $field = $this->fields->getField($name);

        if (!$required && empty($password)) {
            $field->clearErrorMessage();
            return;
        }

        $this->text($name, $password, $required, 6);
        if ($field->hasError()) { return; }

        // Patterns to validate password
        $charClasses = array();
        $charClasses[] = '[:digit:]';
        $charClasses[] = '[:upper:]';
        $charClasses[] = '[:lower:]';

        $pw = '/^';
        $valid = '[';
        foreach($charClasses as $charClass) {
            $pw .= '(?=.*[' . $charClass . '])';
            $valid .= $charClass;
        }
        $valid .= ']{6,}';
        $pw .= $valid . '$/';

        $pwMatch = preg_match($pw, $password);

        if ($pwMatch === false) {
            $field->setErrorMessage('Error al comprobar el password.');
            return;
        } else if ($pwMatch != 1) {
            $field->setErrorMessage(
                    'Debe de contener mayusculas, minusculas y numeros.');
            return;
        }
    }

    public function verify($name, $password, $verify, $required = true) {
        $field = $this->fields->getField($name);
        $this->text($name, $verify, $required, 6);
        if ($field->hasError()) { return; }

        if (strcmp($password, $verify) != 0) {
            $field->setErrorMessage('Los passwords no coinciden.');
            return;
        }
    }
}
?>