﻿<?php

require_once('../model/container_db.php');
require_once('../model/nivel_db.php');
require_once('../email/email_data.php');
require_once('../email/email_send.php');
require_once('utils.php');

// Envio de datos desde la unidad sensora (action = send)
function receive_new_data_from_sensor($dir_ip, $nivel, $temper, $vertic, 
                                      $alarm, $es_recog, $ack, $crc_recibido) {
    
    // Por si hay que enviar e-mails a consecuencia de nuevas alarmas
    $email_pendiente_nivel = $email_pendiente_temper = 
        $email_pendiente_vertic = $email_pendiente_manto = FALSE;
    
    // direccion ip del contenedor
    $contenedor_ip = long2ip($dir_ip); // convierte el int en cadena con la dirección IP 
    
    // obtenemos el contenedor con esta IP
    if($contenedor_ip != "0.0.0.0") { // si dir_ip = null, contenedor_ip = "0.0.0.0"
        $contenedor = get_contenedor_by_ip($contenedor_ip);
    }
    
    // IP = null o no encontrada en la base de datos. Mensaje perdido.
    if(($contenedor_ip == "0.0.0.0") || ($contenedor == null)) {        
        echo "Respuesta desde el Host: &id=???&";              
        return;         
    }
    
    // id del contenedor
    $contenedor_id = (int)$contenedor['contenedor_id'];
    
    // modelo al que pertenece el contenedor
    $modelo = get_modelo_by_contenedor($contenedor_id);
  
    // dato de nivel ?
    if($nivel != null)
    { 
        // estado previo de las alarmas para generar los flancos 
        // que envian los e-mails
        $alarma_nivel_previa = is_activa_alarma_nivel($contenedor_id); 
        $alarma_manto_previa = is_activa_alarma_manto($contenedor_id);
        
        // pasamos el dato absoluto de distancia libre enviado por la 
        // unidad sensora a porcentaje respecto de la altura del contenedor
        $nivel_pc = (int)nivel_abs_to_pc($contenedor_id, $nivel);
        if($nivel_pc > 100) {$nivel_pc = 100;}
        else if($nivel_pc < 0) {$nivel_pc = 0;}
        
        // actualizamos el nivel y en su caso, si se ha realizado una recogida, 
        // actualizamos el número de recogidas acumuladas para el 
        // mantenimiento del contenedor  
        if($es_recog == null) {$recogida = 0;}
        else {$recogida = (int)$es_recog;}        
        add_nivel($contenedor_id, (int)$nivel_pc, $recogida);
        
        // alarma de nivel ?
        // después de la actualización del nivel, miramos si hay alarma
        $alarma_nivel_activa = is_activa_alarma_nivel($contenedor_id);

        // si después de la actualización del nivel hay un flanco 
        // de cambio en la alarma, enviamos el e-mail correspondiente
        if($alarma_nivel_previa !== $alarma_nivel_activa)
        {
            // pdte. EMAIL
            $email_pendiente_nivel = TRUE;
        }        
               
        if($recogida == 1) {
            // alarma de mantenimiento ?
            // después de la actualización de la descarga, miramos 
            // si hay alarma de mantenimiento
            $alarma_manto_activa = is_activa_alarma_manto($contenedor_id);
            
            // si antes no habia alarma y después sí (flanco positivo),         
            // enviamos el e-mail correspondiente
            if(($alarma_manto_previa === false) && ($alarma_manto_activa === true))
            {
                // pdte. EMAIL
                $email_pendiente_manto = TRUE;
            }            
        }
    }
    
    // dato de temperatura ?
    if($temper != null)
    {
        // estado previo de la alarma para generar los flancos 
        // que envian los e-mails
        $alarma_temper_previa = is_activa_alarma_temper($contenedor_id);

        // actualizamos la temperatura
        if($alarm == null) {$alarm = 0;}
        // buscamos el bit de alarma de temperatura 
        // en el byte de alarmas recibido
        $alarma_temper_bit = $alarm & 0x01;
        update_temper($contenedor_id, (int)$temper, $alarma_temper_bit); 
        
        // alarma de temperatura ? :        
        $alarma_temper_activa = is_activa_alarma_temper($contenedor_id);
        
        // si después de la actualización de la temperatura hay un flanco 
        // de cambio en la alarma, enviamos el e-mail correspondiente
        if($alarma_temper_previa !== $alarma_temper_activa)
        {
            // pdte. EMAIL
            $email_pendiente_temper = TRUE;            
        }                    
    }

    // dato de verticalidad ?
    if($vertic != null)
    {
        // estado previo de la alarma para generar los flancos 
        // que envian los e-mails
        $alarma_vert_previa = is_activa_alarma_vertic($contenedor_id);
        
        // actualizamos la verticalidad
        if($alarm == null) {$alarm = 0;}
        // buscamos el bit de alarma de verticalidad 
        // en el byte de alarmas recibido
        $alarma_vertic_bit = ($alarm & 0x02) >> 1;
        update_vertic($contenedor_id, (int)$vertic, $alarma_vertic_bit);        
        
        // alarma de verticalidad ? :  
        $alarma_vert_activa = is_activa_alarma_vertic($contenedor_id);

        // si después de la actualización de la verticalidad hay un flanco 
        // de cambio en la alarma, enviamos el e-mail correspondiente        
        if($alarma_vert_previa !== $alarma_vert_activa)
        {
            // pdte. EMAIL
            $email_pendiente_vertic = TRUE;
        }        
    }
    
    // Hay que enviar emails ?  
    // Detectamos la/s alarma/s que han variado (flanco) 
    // para señalarlo en el email
    if (($email_pendiente_nivel === TRUE) || ($email_pendiente_temper === TRUE) ||
        ($$email_pendiente_vertic === TRUE) || ($email_pendiente_manto === TRUE))
    {
        $email = new Email($contenedor_id);        
                
        // datos de nivel:
        $email->addField('Nivel', 'Valor Actual (%):', 'Set Alarma (%):', 
                $nivel_pc, $modelo['porcentaje_alarma_nivel'], 
                $alarma_nivel_activa, $email_pendiente_nivel);
        
        // datos de temperatura:
        $email->addField('Temperatura', 'Valor Actual (&deg;C):', 'Set Alarma (&delta;&deg;C):',
                $temper / 10.0, 2, $alarma_temper_activa, $email_pendiente_temper);
    
        // datos de verticalidad:
        $email->addField('Verticalidad', 'Valor Actual (&deg;):', 'Set Alarma (&deg;):',
                $vertic / 10.0, 45, $alarma_vert_activa, $email_pendiente_vertic);    
    
        // datos de mantenimiento:
        
        // recogidas acumuladas por el contenedor desde el último mantenimiento
        $recogidas_acumuladas_manto = get_recogidas_acumuladas($contenedor_id);
        
        $email->addField('Mantenimiento', 'Descargas:', 'Set Alarma:',
                $recogidas_acumuladas_manto, $modelo['alarma_mantenimiento'], 
                $alarma_manto_activa, $email_pendiente_manto);    

        // se envia el email a todos los usuarios abilitados para recibirlo
        send_emails($contenedor_id, $email->get_HTML_Header(), 
                $email->get_HTML_Fields(), $email->get_HTML_Footer());
   
    }
    
    // solicitado reconocimiento de datos desde la unidad sensora ?
    if(($ack != null) && ($ack == 1)) {

        // enviar el mismo crc_recibido (que ya se ha comprobado como correcto) 
        // a la unidad sensora :    
        $string_to_send = 'Respuesta desde el Host: &dir_ip=' . $contenedor_ip . 
                          '&crc=' . $crc_recibido . '&'; 
        
        echo $string_to_send; 
    }
    
}

// Petición de envio de datos desde la unidad sensora (action = request)
function send_settings_to_sensor($dir_ip, $get_per_actualiza, $get_per_nivel) {
    
    // direccion ip del contenedor
    $contenedor_ip = long2ip($dir_ip); // convierte el int en cadena con la dirección IP 
    
    // obtenemos el contenedor con esta IP
    if($contenedor_ip != "0.0.0.0") { // si dir_ip = null, contenedor_ip = "0.0.0.0"
        $contenedor = get_contenedor_by_ip($contenedor_ip);
    }
    
    // IP = null o no encontrada en la base de datos. Mensaje perdido.
    if(($contenedor_ip == "0.0.0.0") || ($contenedor == null)) {        
        echo "Respuesta desde el Host: &id=???&";                    
        return;         
    }    
    
    // id del contenedor
    $contenedor_id = (int)$contenedor['contenedor_id'];
    
    // modelo al que pertenece el contenedor
    $modelo = get_modelo_by_contenedor($contenedor_id);    
    
    // construimos la cadena de datos para envío
    $data_clear = '&dir_ip=' . $contenedor_ip;

    // incluir periodo para actualizacion de datos ?
    if(($get_per_actualiza != null) && ($get_per_actualiza == 1)) { 
        $data_clear .= ('&set_per_actualiza=' .
                       $modelo['periodo_actualizacion_datos']);       
    }
    
    // incluir periodo para medida de nivel ?
    if(($get_per_nivel != null) && ($get_per_nivel == 1)) {    
        $data_clear .= ('&set_per_nivel=' .
                       $modelo['periodo_medida_nivel']);       
    }
    
    // cálculo del crc de los datos
    $calculated_crc = crc16($data_clear, 0);
    
    // cadena final para envío (se añade el crc)
    $string_to_send = 'Respuesta desde el Host: ' . $data_clear . 
                      '&crc=' . $calculated_crc . '&';
    
    // enviamos los datos a la unidad sensora  
    echo $string_to_send; 
}

?>
