<?php 
require_once('../util/main.php');
require_once('../util/valid_user.php');
require_once('../model/centro_db.php');
require_once('../model/ubicacion_db.php');
require_once('../model/container_db.php');
require_once('../model/residuo_db.php');
require_once('../model/nivel_db.php');
require_once('../email/email_send.php');
require_once('../rest/main.php');


$action = strtolower(filter_input(INPUT_POST, 'action'));

if (isset($_SESSION['admin'])) {
    if ($action == null) {
        $action = filter_input(INPUT_GET, 'action');   // $action = logout
        if($action == null) {$action = logout;}
    }
} elseif ($action == 'login') {
    $action = 'login';  // $action = login 
} else {
    $action = 'view_login'; // $action = view_login 
}

switch ($action) {

    case 'list_centros':   
        
        // si el usuario está logeado, obtiene los centros de trabajo 
        // a los que tiene acceso
        if ($_SESSION != NULL && isset($_SESSION['admin']))
        { 
            $centros = get_centros($_SESSION['admin']['usuario_id']);
            if(!empty($centros))
            {
                $centro_id = filter_input(INPUT_GET, 'centro_id', FILTER_VALIDATE_INT);                
                $current_centro = get_centro($centro_id);
                $current_centro_ubicaciones = 
                    get_ubicaciones_by_centro($current_centro['centro_id']);
            }
        }            
        // muestra la lista de centros
        include('centros/centros_list.php');
        break; 
        
    case 'list_containers_ubicacion':
        
        // centro de trabajo actual
        $current_centro_id = filter_input(INPUT_GET, 'current_centro_id', FILTER_VALIDATE_INT);
        $current_centro = get_centro($current_centro_id);
        
        // contenedores situados en la ubicación (isla) actual
        $current_ubicacion_id = filter_input(INPUT_GET, 'ubicacion_id', FILTER_VALIDATE_INT);
        $current_ubicacion = get_ubicacion($current_ubicacion_id);
        $current_ubicacion_containers = get_containers_by_ubicacion($current_ubicacion_id);
        
        // para el menú lateral izquierdo
        $centros = get_centros($_SESSION['admin']['usuario_id']);

        // muestra la lista de contenedores
        include('../forms/containers_by_ubicacion.php');
        break;
    
    case 'view_container': // Tiempo real
        
        // container seleccionado
        $current_container_id = filter_input(INPUT_GET, 'container_id', FILTER_VALIDATE_INT);
        $current_container = get_container($current_container_id);
        
        // centro de trabajo actual, del que depende el container seleccionado
        $current_centro_id = filter_input(INPUT_GET, 'current_centro_id', FILTER_VALIDATE_INT);
        $current_centro = get_centro($current_centro_id);        
        
        // ubicación (isla) actual a la que pertenece el container seleccionado
        $current_ubicacion_id = filter_input(INPUT_GET, 'current_ubicacion_id', FILTER_VALIDATE_INT);
        $current_ubicacion = get_ubicacion($current_ubicacion_id); 
        
        // tipo de residuo para el que se dedica el container seleccionado
        $current_residuo_id = $current_container['residuo_id'];
        $current_residuo = get_residuo($current_residuo_id);
        
        // modelo al que pertenece el container
        $current_modelo_id = $current_container['modelo_id'];
        $current_modelo_contenedor = get_modelo($current_modelo_id);
        
        // Cantidad de descargas acumuladas desde el último mantenimiento
        // del contenedor actual.
        // Igual a cantidad de recogidas en la tabla 'recogidas' con
        // fecha posterior al campo 'ultimo_mantenimiento' del contenedor 
        // actual en la tabla 'contenedores'
        $manto_actual_value = get_recogidas_acumuladas($current_container_id);
                
        // variables físicas       
        $nivel_actual_value = (int)get_nivel($current_container_id)['porcentaje']; 
        // la temperatura se representa en KF con un decimal. de ahí la divisió por 10
        $temp_actual_value = ((int)get_container($current_container_id)['temperatura_actual'] / 10);
        // la verticalidad se representa en KF con un decimal. de ahí la divisió por 10
        $vert_actual_value = ((int)get_container($current_container_id)['verticalidad_actual'] / 10);
        
        // alarmas       
        $alarma_nivel = is_activa_alarma_nivel($current_container_id);
        $alarma_temperatura = is_activa_alarma_temper($current_container_id);
        $alarma_verticalidad = is_activa_alarma_vertic($current_container_id);
        $alarma_mantenimiento = ($manto_actual_value > 
            $current_modelo_contenedor['alarma_mantenimiento']);
        
        if ($alarma_nivel == true) {$color_alarma_nivel = 'red';}
        else {$color_alarma_nivel = 'lime';}
        
        if ($alarma_temperatura == true) {$color_alarma_temp = 'red';}
        else {$color_alarma_temp = 'lime';}

        if ($alarma_verticalidad == true) {$color_alarma_vert = 'red';}
        else {$color_alarma_vert = 'lime';}        
        
        if ($alarma_mantenimiento == true) {$color_alarma_manto = 'red';}
        else {$color_alarma_manto = 'lime';}
        
        // Fecha hora de la última recepción de datos desde la unidad sensora        
        $ultima_actualizacion_temper_o_vert = $current_container['ultima_actualizacion'];
        $datetime1 = strtotime($ultima_actualizacion_temper_o_vert);
        $ultima_actualizacion_nivel =  get_nivel($current_container_id)['fecha_hora'];       
        $datetime2 = strtotime($ultima_actualizacion_nivel);

        if($datetime1 > $datetime2) 
            {$ultima_actualizacion = date('d/m/Y H:i:s', $datetime1);} 
        else {$ultima_actualizacion = date('d/m/Y H:i:s', $datetime2);} 
       
        // para el menú lateral izquierdo
        $pagina_atras = true;
        $centros = get_centros($_SESSION['admin']['usuario_id']);        

        // muestra la página principal del contenedor (tiempo real)
        include('../forms/container_main.php');
        break;
        
    case 'update_container': 

        $contenedor_id = filter_input(INPUT_POST, 'contenedor_id', FILTER_VALIDATE_INT);
        $centro_id = filter_input(INPUT_POST, 'centro_id', FILTER_VALIDATE_INT);
        $ubicacion_id = filter_input(INPUT_POST, 'ubicacion_id', FILTER_VALIDATE_INT);
        
        // Validación sencilla de los datos
        if ($contenedor_id === false || $centro_id === false || 
            $ubicacion_id === false) {
            $error_message = 'Dato inv&aacute;lido. Revisar los valores e intentar de nuevo.';
            include('../errors/error.php');                                 
        }  else {
            // actualicación de la fecha del último mantenimiento en la 
            // tabla 'contenedores' si se ha pulsado el boton de reset 
            // de mantenimiento
            if (isset($_POST['boton_reset_manto'])) { 
                
                update_contenedor_manto($contenedor_id); 

                // si se ha validado el mantenimiento del contenedor, se 
                // envian los e-mails correspondientes:

                // estado en la entrada a la página       
                $alarma_manto_previa = (bool)filter_input(INPUT_POST, 'estado_alarma_manto');

                // estado en la salida de la página
                $alarma_manto_actual = is_activa_alarma_manto($contenedor_id);

                // detección de flanco negativo para envío de e-mails
                if($alarma_manto_previa === true && $alarma_manto_actual === false)
                {
                    // pdte. EMAIL
                } 
            }
                        
            // muestra de nuevo la página 'container_main' 
            // (la misma de la que viene, actualizada)
            header("Location: ./?action=view_container&container_id=" . $contenedor_id .
                   "&current_centro_id=" . $centro_id . 
                   "&current_ubicacion_id=" . $ubicacion_id);     
        }      
                
        break;        
    
    case 'list_modelos':
        
        // Obtener los modelos de contenedor existentes
        $modelos_contenedor = get_modelos_contenedor();
        
        // para el menú lateral izquierdo
        $pagina_atras = true;
        $centros = get_centros($_SESSION['admin']['usuario_id']);        
        
        // muestra la página de listado de modelos de contenedor para 
        // seleccionar el modelo para el que se editarán los ajustes
        include('account/modelos_list.php');
        break;
    
    case 'edit_modelo':
        
        // modelo de contenedor seleccionado
        $current_modelo_id = filter_input(INPUT_GET, 'modelo_id', FILTER_VALIDATE_INT);
        $current_modelo_contenedor = get_modelo($current_modelo_id);
        // para el menú lateral izquierdo
        $pagina_atras = true;
        $centros = get_centros($_SESSION['admin']['usuario_id']);        
        
        // muestra la página de edicción de modelo de contenedor
        include('account/modelo_edit.php');
        break;
    
    case 'update_modelo': 
        
        $modelo_id = filter_input(INPUT_POST, 'modelo_id', FILTER_VALIDATE_INT);
        $periodo_act_datos = filter_input(INPUT_POST, 'per_act_datos', FILTER_VALIDATE_INT);
        $periodo_act_nivel = filter_input(INPUT_POST, 'per_act_nivel', FILTER_VALIDATE_INT);
        $alarma_nivel = filter_input(INPUT_POST, 'alarma_nivel', FILTER_VALIDATE_INT);
        $alarma_manto = filter_input(INPUT_POST, 'alarma_manto', FILTER_VALIDATE_INT);

        // Validación sencilla de los datos
        if ($modelo_id === false || $periodo_act_datos === false ||
            $periodo_act_nivel === false || $alarma_nivel === false ||   
            $alarma_manto === false) {
                $error_message = 'Dato inv&aacute;lido. Revisar los valores e intentar de nuevo.';
                include('../errors/error.php');
        } else {

            // actualicación de la tabla 'modelos' en la base de datos
            update_modelo($modelo_id, $periodo_act_datos, $periodo_act_nivel, 
                          $alarma_nivel, $alarma_manto);

            // si el usuario está logeado, obtiene los centros de trabajo 
            // a los que tiene acceso
            if ($_SESSION != NULL && isset($_SESSION['admin']))
            { 
                $centros = get_centros($_SESSION['admin']['usuario_id']);
                if(!empty($centros))
                {
                    // se lista el primer centro al que tiene acceso
                    $centro_id = 1;                
                    $current_centro = get_centro($centro_id);
                    $current_centro_ubicaciones = 
                        get_ubicaciones_by_centro($current_centro['centro_id']);
                }
            }
            
            // muestra de nuevo la página 'modelo_edit' 
            // (la misma de la que viene, actualizada)
            header("Location: ./?action=edit_modelo&modelo_id=" . $modelo_id);
        }        
        break;
}
?>
