
// --- file led.h ---

/**
 * Definiciones de cabecera para el fichero led.c
 *
 * Miguel A. Fdez. Cela
 *
 * revision 1.0 date 16/02/2016
 */

#ifndef __LED_H
#define __LED_H

#include "type.h"

#define LED_2	0, 22	// Led 2 (P0.22): led 2 port (0), led 2 bit (22)


/** Inicializa GPIO0 para acceder al led
 *
 * @precondition no
 *
 * @param 	ledPort: El puerto en el que está conectado el led.
 * @param	ledBit: El bit del puerto en el que está conectado el led.
 *
 * @return void
 */
void Led_ledInit(uint32_t ledPort, uint32_t ledBit);

/** Enciende el led
 *
 * @precondition Se ha inicializado GPIO0 para acceder al led
 *
 * @param 	ledPort: El puerto en el que está conectado el led.
 * @param	ledBit: El bit del puerto en el que está conectado el led.
 *
 * @return void
 */
void Led_ledOn(uint32_t ledPort, uint32_t ledBit);

/** Apaga el led
 *
 * @precondition Se ha inicializado GPIO0 para acceder al led
 *
 * @param 	ledPort: El puerto en el que está conectado el led.
 * @param	ledBit: El bit del puerto en el que está conectado el led.
 *
 * @return void
 */
void Led_ledOff(uint32_t ledPort, uint32_t ledBit);

/** Invierte el estado actual del led
 *
 * @precondition Se ha inicializado GPIO0 para acceder al led
 *
 * @param 	ledPort: El puerto en el que está conectado el led.
 * @param	ledBit: El bit del puerto en el que está conectado el led.
 *
 * @return void
 */
void Led_ledToggle(uint32_t ledPort, uint32_t ledBit);

#endif
