/*
 * log.h
 *
 * This module allows send log strings through an UART port
 *
 * author: Miguel A. Fdez.
 *
 * revision 1.0 date 7/4/2015
 */

#ifndef LOG_H_
#define LOG_H_

#include "type.h"

/** Initializes an UART port by means of PrintF_start()
 *
 * @precondition The UART port is available
 *
 * @param portNum   the UART port to initialize
 * @param baudrate  the baud rate for the port
 *
 * @return TRUE or FALSE. Returns FALSE if the interrupt handler
 *         can't be installed to the VIC table or if the hardware
 *         port don't is present, otherwise returns TRUE
 */
bool_t Log_start(uint32_t portNum, uint32_t baudrate);

/** Prints a log string by means of PrintF_print()
 *
 * @precondition the log UART port has been initialized
 *
 * @param logString     pointer to the string that contains the log text
 * @param ...     		list of arguments for the logString
 *
 * @return TRUE or FALSE. Returns FALSE if the UART has not been initialized or if the
 * 		   hardware port is not present, otherwise returns TRUE
 */
bool_t Log_log(char* logString, ...);

#endif /* LOG_H_ */
