/*
 * power.h
 *
 *  Created on: 13/11/2015
 *      Author: NXP Semiconductors, 2014.
 *      Modified: Miguel A. Fdez.
 */

#ifndef POWER_H_
#define POWER_H_

/**
 * @brief LPC17xx_40xx Power Management Unit register block structure
 */
typedef struct {
	__IO uint32_t PCON;		/*!< Offset: 0x000 Power control Register (R/W) */
} LPC_PMU_T;

/**
 * @brief LPC17xx_40xx low power mode type definitions
 */
typedef enum CHIP_PMU_MCUPOWER {
	PMU_MCU_SLEEP = 0,		/*!< Sleep mode */
	PMU_MCU_DEEP_SLEEP,		/*!< Deep Sleep mode */
	PMU_MCU_POWER_DOWN,		/*!< Power down mode */
	PMU_MCU_DEEP_PWRDOWN	/*!< Deep power down mode */
} CHIP_PMU_MCUPOWER_T;

/**
 * PMU PCON register bit fields & masks
 */
#define PMU_PCON_PM0_FLAG			(1 << 0)
#define PMU_PCON_PM1_FLAG			(1 << 1)
#define PMU_PCON_BODRPM_FLAG		(1 << 2)
#define PMU_PCON_BOGD_FLAG			(1 << 3)
#define PMU_PCON_BORD_FLAG			(1 << 4)
#define PMU_PCON_SMFLAG          	(1 << 8)	/*!< Sleep mode flag */
#define PMU_PCON_DSFLAG          	(1 << 9)	/*!< Deep Sleep mode flag */
#define PMU_PCON_PDFLAG             (1 << 10)	/*!< Power-down flag */
#define PMU_PCON_DPDFLAG            (1 << 11)	/*!< Deep power-down flag */

/**
 * Estructura LPC_PMU_BASE mapeada a la dirección base
 */
#define LPC_PMU_BASE 0x400FC0C0
#define LPC_PMU ((LPC_PMU_T *) LPC_PMU_BASE)

/**
 * @brief	Place the MCU in a low power state
 * @param	pPMU		: Pointer to PMU register block
 * @param	SleepMode	: Sleep mode
 * @return	None
 */
void Power_sleep(LPC_PMU_T *pPMU, CHIP_PMU_MCUPOWER_T sleepMode);

#endif /* POWER_H_ */
