/*
 * gpio.c
 *
 *  Created on: 3/11/2015
 *      Author: Miguel A. Fdez.
 */

#include "LPC17xx.h"
#include "gpio.h"

// Direcciones de los puertos GPIO

static LPC_GPIO_TypeDef (* const LPC_GPIO[5]) = {LPC_GPIO0, LPC_GPIO1, LPC_GPIO2, LPC_GPIO3, LPC_GPIO4};
/*-----------------------------------------------------------*/

void GPIO_setDir(uint32_t portNum, uint32_t bitPos, uint32_t dir)
{
	if(dir == TRUE) LPC_GPIO[portNum]->FIODIR |= (1 << bitPos);  // Output
	else if(dir == FALSE) LPC_GPIO[portNum]->FIODIR &= (~(1 << bitPos));  // Input
}
/*-----------------------------------------------------------*/

void GPIO_setPull(uint32_t portNum, uint32_t bitPos, uint32_t pull)
{
	switch(portNum)
	{
		case 0:
			if((bitPos > 11) && (bitPos < 15)) break;	// bits reservados
			if (bitPos < 16) {
				bitPos = bitPos * 2;
				LPC_PINCON->PINMODE0 |= (pull << bitPos);
			}
			else if (bitPos < 27) {
				bitPos = bitPos - 16;
				bitPos = bitPos * 2;
				LPC_PINCON->PINMODE1 |= (pull << bitPos);
			}
			break;

		case 1:
			if((bitPos == 2) || (bitPos == 3) || (bitPos == 5) || (bitPos == 6) ||
			   (bitPos == 7) || (bitPos == 11) || (bitPos == 12) || (bitPos == 13)) break;	// bits reservados
			if (bitPos < 16) {
				bitPos = bitPos * 2;
				LPC_PINCON->PINMODE2 |= (pull << bitPos);
			} else if (bitPos > 15) {
				bitPos = bitPos - 16;
				bitPos = bitPos * 2;
				LPC_PINCON->PINMODE3 |= (pull << bitPos);
			}
			break;

		case 2:
			if (bitPos < 14) {
				bitPos = bitPos * 2;
				LPC_PINCON->PINMODE4 |= (pull << bitPos);
			}
			break;

		case 3:
			if (bitPos == 25) LPC_PINCON->PINMODE7 |= (pull << 18);
			else if (bitPos == 26) LPC_PINCON->PINMODE7 |= (pull << 20);
			break;

		case 4:
			if (bitPos == 28) LPC_PINCON->PINMODE9 |= (pull << 24);
			else if (bitPos == 29) LPC_PINCON->PINMODE9 |= (pull << 26);
	}
}
/*-----------------------------------------------------------*/

void GPIO_setValue(uint32_t portNum, uint32_t bitPos, bool_t bitVal)
{
	if (bitVal == FALSE) LPC_GPIO[portNum]->FIOCLR = (1 << bitPos);
	else if (bitVal == TRUE) LPC_GPIO[portNum]->FIOSET = (1 << bitPos);
}
/*-----------------------------------------------------------*/

bool_t GPIO_getValue(uint32_t portNum, uint32_t bitPos)
{
    uint32_t value;

	LPC_GPIO[portNum]->FIOMASK = ~(1 << bitPos);
	value = LPC_GPIO[portNum]->FIOPIN;
	value = (value >> bitPos);
	LPC_GPIO[portNum]->FIOMASK = 0x00000000;

    return (value > 0);
}
/*-----------------------------------------------------------*/
