/*
 * log.c
 *
 *  Created on: 7/4/2015
 *      Author: Miguel A. Fdez.
 */

#include "FreeRTOS.h"
#include "task.h"
#include <stdarg.h> // for va_list, va_start(), va_end()
#include <string.h> // for memset()
#include <stdio.h>	// for vsprintf()
#include "printf.h"
#include "log.h"

volatile uint32_t l_Log_uartPort = MAX_UART_PORTS;	// The Log port

bool_t Log_start(uint32_t portNum, uint32_t baudrate)
{
	if(portNum < MAX_UART_PORTS)
	{
		// Escritura del puerto para el Log en la inicialización
		l_Log_uartPort = portNum;

		// Concurrencia protegida por PrintF_start()
		return (PrintF_start(l_Log_uartPort, baudrate));
	}
	else return FALSE;
}
/*-----------------------------------------------------------*/

bool_t Log_log(char* logString, ...)
{
	// Thread-safe: Variables distintas en cada llamada (se usa la pila).
	char msg[UART_TX_BUFSIZE]; memset(msg, 0x00, sizeof(msg));
	va_list args;
	va_start(args, logString);
	vsprintf(msg, logString, args);
	va_end(args);

	// l_Log_uartPort, una vez iniciada en Log_start(), solo se lee.
	// maxUART_PORTS es una definición de solo lectura.
	if(l_Log_uartPort < MAX_UART_PORTS)
	{
		// Concurrencia protegida por PrintF_print()
		return (PrintF_print(l_Log_uartPort, "%s\r\n", msg));
	}
	else return FALSE;
}
/*-----------------------------------------------------------*/

