/*
 *  control.h
 *
 *  Created on: 26/11/2015
 *      Author: Miguel A. Fdez.
 */

#ifndef INC_CONTROL_H_
#define INC_CONTROL_H_

// número de elementos de la cola
#define xQUEUE_LENGTH	3	// estructuras de temperatura, verticalidad y nivel

// Identificadores de las estructuras de tipo 'ACTUAL_DATA'
#define ID_NO			    0
#define ID_NIVEL		    1
#define ID_TEMPERATURA	    2
#define ID_VERTICALIDAD     3
#define ID_DESCARGA		    4

// Switch montado en la placa del sensor para dividir por 10 el tiempo
// ajustado en power-down y hacer pruebas más rápido (solo para pruebas)
#define PCB_TEST_SWITCH		0, 7	// PCB test switch (SW2). (P0.7): switch port (0), switch bit (7)

// Estructura de los elementos de la cola en la que van escribiendo las tareas de
// temperatura, verticalidad y nivel y que lee la tarea consumidora
typedef struct
{
	uint8_t id; 	// el identificador del tipo de dato (nivel, temperatura, verticalidad o descarga).
	int16_t value; 	// el valor del dato
	bool_t alarm;   // alarma activa ?	FALSE:No, TRUE:Si.
	bool_t alarmFlange;  // Cambio del estado de alarma en el ciclo actual ? FALSE:No, TRUE: Si.
						 // (Es indiferente que el flanco sea positivo o negativo).
} ACTUAL_DATA;


/** Getter para la variable local 'l_is_FirstCycle'
 * 		La variable indica si el ciclo actual es el primero después de una
 * 		alimentación general de bateria (ejemplos: marcha inicial del
 * 		módulo sensor o cámbio de bateria)
 *
 * @param None
 *
 * @return El valor de la variable. TRUE si es el primer ciclo, FALSE en caso contrario.
 */
bool_t Control_getIsFirstCicle(void);

/** Setter para la variable local 'l_is_FirstCycle'.
 * 		La variable indica si el ciclo actual es el primero después de una
 * 		alimentación general de bateria (ejemplos: marcha inicial del
 * 		módulo sensor o cámbio de bateria)
 *
 * @param El valor de la variable. TRUE si es el primer ciclo, FALSE en caso contrario.
 *
 * @return None
 */
void Control_setIsFirstCicle(bool_t value);

/** Getter para la variable local 'l_pedir_DatosAlHost'
 * 		La variable indica si hay que pedir los datos de ajuste al Host en
 * 		el ciclo actual (TRUE) o no (FALSE)
 *
 * @param None
 *
 * @return El valor de la variable. TRUE si hay que pedir datos, FALSE en caso contrario.
 */
bool_t Control_getPedirDatosAlHost(void);

/** Setter para la variable local 'l_pedir_DatosAlHost'.
 * 		La variable indica si hay que pedir los datos de ajuste al Host en
 * 		el ciclo actual (TRUE) o no (FALSE)
 *
 * @param El valor de la variable. TRUE si hay que pedir datos, FALSE en caso contrario.
 *
 * @return None
 */
void Control_setPedirDatosAlHost(bool_t value);

/** Getter para la variable local 'l_medir_nivel_en_este_ciclo'
 *
 * 		La variable indica si en el ciclo actual se ha
 * 		de medir el nivel o no
 *
 * @param None
 *
 * @return El valor de la variable. TRUE si se ha de medir el nivel, FALSE en caso contrario.
 */
bool_t Control_getMedirNivelEnEsteCiclo(void);

/** Setter para la variable local 'l_medir_nivel_en_este_ciclo'
 *
 * 		La variable indica si en el ciclo actual se ha
 * 		de medir el nivel o no
 *
 * @param El valor de la variable. TRUE si se ha de medir el nivel, FALSE en caso contrario.
 *
 * @return None
 */
void Control_setMedirNivelEnEsteCiclo(bool_t value);

/** Getter para la variable local 'l_descarga_Detectada'
 *
 * 		La variable indica si en el ciclo actual se ha
 * 		detectado una descarga del contenedor
 *
 * @param None
 *
 * @return El valor de la variable. TRUE si se ha detectado descarga, FALSE en caso contrario.
 */
bool_t Control_getDescargaDetectada(void);

/** Setter para la variable local 'l_descarga_Detectada'
 *
 * 		La variable indica si en el ciclo actual se ha
 * 		detectado una descarga del contenedor
 *
 * @param El valor de la variable. TRUE si se ha detectado descarga, FALSE en caso contrario.
 *
 * @return None
 */
void Control_setDescargaDetectada(bool_t value);


/** Gestor de la lógica de los datos
 *
 * @preconditions Todos los elementos hardware han sido inicializados y están funcionando
 *
 * @param nivel  		Estructura de tipo 'ACTUAL_DATA' con los datos obtenidos del sensor de nivel
 * @param temperatura  	Estructura de tipo 'ACTUAL_DATA' con los datos obtenidos del sensor de temperatura
 * @param verticalidad  Estructura de tipo 'ACTUAL_DATA' con los datos obtenidos del acelerómetro
 *
 * @return None
 */
void Control_manager(ACTUAL_DATA *nivel, ACTUAL_DATA *temperatura, ACTUAL_DATA *verticalidad);


#endif /* INC_CONTROL_H_ */
