/*
 * host.h
 *
 *  Created on: 21/10/2015
 *      Author: Miguel A. Fdez.
 */

#ifndef HOST_H_
#define HOST_H_

#define HOST_SEMAPHOR_TAKE_WAIT_MS	60000 // milliseconds to wait for take the Host semaphor

/** Envía datos al Host
 *
 * @preconditions El Wifly está inicializado y conectado a una red wifi con conexión a internet.
 *
 * @param nivel  		El valor actual del nivel de residuos
 * @param temperatura   El valor actual de la temperatura
 * @param verticalidad  El valor actual de la verticalidad
 * @param alarma  		El byte con el estado de las alarmas
 * @param es_recogida  	El dato que indica si acaba de producirse una recogida o no. 1-si, 0-no
 * @param solicitarAck  Solicitud de reconocimiento
 *
 * @return TRUE or FALSE. TRUE si la petición se ha enviado correctamente, FALSE en caso contrario.
 */
bool_t Host_send(int16_t nivel, int16_t temperatura, int16_t verticalidad,
		         uint8_t alarma, uint8_t es_recogida, bool_t solicitarAck);

/** Recibe datos del Host
 *
 * @preconditions El Wifly está inicializado y conectado a una red wifi con conexión a internet.
 *
 * @per_actualiza_datos			El valor de salida que indica el periodo para actuañización de
 * 								datos desde el host
 * @param per_actualiza_nivel	El valor de salida que indica el periodo para hacer las medidas
 * 								de nivel
 *
 * @return TRUE or FALSE. TRUE si los datos se han recibido correctamente, FALSE en caso contrario.
 */
bool_t Host_request(uint16_t *per_actualiza_datos, uint16_t *per_actualiza_nivel);

#endif /* HOST_H_ */
