/*
 * nivel.h
 *
 *  Created on: 17/11/2015
 *      Author: Miguel A. Fdez.
 */

#ifndef INC_NIVEL_H_
#define INC_NIVEL_H_

#include "type.h"
#include "control.h"

#define NIVEL_POWER_PIN		0, 5	// gpio port and bit de control de la alimentación del sensor (P0.5)
#define NIVEL_READ_PIN		0, 17	// gpio port and bit que indica al sensor cuando debe de hacer una lectura (P0.17)

#define NIVEL_UART_TIMEOUT	60	// Timeout en mS para obtener la respuesta del sensor (>50 ver hoja de datos del sensor)

#define NIVEL_SEMAPHORE_TAKE_WAIT_MS	60000 	//  milisegundos de espera para obtener el semáforo

/** Inicialización del sensor de nivel:
 *    - Inicializa el pin del micro que controla la alimentación del sensor de nivel como salida
 *      y habilita la alimentación
 * 	  - Inicializa el puerto UART del LPC1769 utilizado para comunicarse con el sensor de nivel
 *
 * @preconditions El puertos UART está disponible en el hardware y una salida digital
 *                del LPC1769 está conectada a la entrada de control de alimentación
 *                del sensor (ver esquema FPF2104).
 *
 * @param portNum   El puerto UART para comunicación con el sensor de nivel
 * @param baudrate  El baud rate para el puerto
 *
 * @return TRUE or FALSE. Retorna TRUE si la inicialización ha sido correcta,
 *                        FALSE en caso contrario.
 */
bool_t Nivel_init(uint32_t portNum, uint32_t baudrate);


/** Desconecta la alimentación del sensor de nivel.
 *
 * @preconditions None.
 *
 * @param None.
 *
 * @return None.
 */
void Nivel_powerOff(void);


/** Distancia que queda libre hasta el nivel actual de residuos.
 *
 * @preconditions Se ha llamado anteriormente a Nivel_init() para iniciar el medidor de distancia
 *
 * @param Puntero a la estructura de datos en la que se obtendrán los valores del nivel
 *
 * @return None
 */
void Nivel_get(ACTUAL_DATA *nivel);


#endif /* INC_NIVEL_H_ */
