/*
 * temperatura.h
 *
 *  Created on: 19/11/2015
 *      Author: Miguel A. Fdez.
 */

#ifndef INC_TEMPERATURA_H_
#define INC_TEMPERATURA_H_

#include "type.h"
#include "control.h"

#define TEMP_POWER_PIN		0, 4	// gpio port and bit to power the temperature sensor (P0.4)
#define TEMP_ANALOG_CHANNEL	3 		// Canal analógico para lectura de la temperatura

#define TEMP_ADC_SAMPLES	(uint32_t) 5 	// número de medidas de la temperatura para el posterior filtrado

#define TEMP_SEMAPHORE_TAKE_WAIT_MS	60000 	// milisegundos de espera para obtener el semáforo


/**
 * Inicialización del sensor de temperatura:
 *    - Inicializa el pin del micro que controla la alimentación del sensor
 *      de temperatura como salida y habilita la alimentación
 *
 * @preconditions Las entradas-salidas del micro están conectadas a los
 *                correspondientes pins del sensor de temperatura (ver esquema).
 *
 * @param None
 *
 * @return None
 *
 */
void Temperatura_init(void);


/**
 * Obtiene la temperatura actual y determina si hay alarma por temperatura.
 *
 * @preconditions Se ha llamado anteriormente a Temperatura_init() para iniciar el
 *                sensor de temperatura
 *
 * @param *temperatura Puntero a la estructura de tipo 'ACTUAL_DATA' utilizada para
 * 					   almacenar los valores de temperatura
 *
 * @return None
 *
 */
void Temperatura_get(ACTUAL_DATA *temperatura);


#endif /* INC_TEMPERATURA_H_ */
