/*
 * verticalidad.h
 *
 *  Created on: 23/11/2015
 *      Author: Miguel A. Fdez.
 */

#ifndef INC_VERTICALIDAD_H_
#define INC_VERTICALIDAD_H_

#include "type.h"
#include "control.h"

#define ACEL_SLEEP_PIN		1, 31	// gpio port and bit to put the accelerometer in sleep mode (P1.31)
#define ACEL_SELFTEST_PIN	2, 5	// gpio port and bit to enable the acelerometer selftest (P2.5)

#define ACEL_0G  		1300	// salida aprox. en mV del acelerómetro para 0g (ajustado para el eje Z)
#define ACEL_SENSIVITY	800 	// sensibilidad aprox. del acelerómetro en mV/g

// número de medidas en cada uno de los tres canales de entrada al conversor AD del micro
// desde el acelerómetro para el posterior filtrado
#define ACEL_ADC_SAMPLES	(uint32_t) 5

#define ACEL_SEMAPHORE_TAKE_WAIT_MS	60000 	// milisegundos de espera para obtener el semáforo

/**
 * Inicialización del acelerómetro:
 *    - Inicializa el pin del micro que pone en 'sleep' al acelerómetro como salida
 *      y lo habilita
 *    - Inicializa el pin del micro que controla el 'self-test' del acelerómetro como salida
 *      y deshabilita el self-test
 *
 *
 * @preconditions Las entradas-salidas del micro están conectadas a los
 *                correspondientes pins del acelerómetro (ver esquema).
 *
 * @param None
 *
 * @return None
 *
 */
void Verticalidad_init(void);


/**
 * Determina si hay alarma por verticalidad.
 *
 * @preconditions Se ha llamado anteriormente a Verticalidad_init() para iniciar el acelerómetro
 *
 * @param None
 *
 * @return TRUE si la alarma por verticalidad está activa, FALSE en caso contrario
 *
 */
void Verticalidad_get(ACTUAL_DATA *verticalidad);


#endif /* INC_VERTICALIDAD_H_ */
